pub enum ShellError {
ModelNotFound {
path: PathBuf,
hint: String,
},
ModelCorrupted {
path: PathBuf,
hint: String,
},
ModelLoadFailed {
path: PathBuf,
cause: String,
},
InvalidInput {
message: String,
},
HistoryParseError {
path: PathBuf,
line: usize,
cause: String,
},
SecurityViolation {
command: String,
reason: String,
},
}Expand description
Errors that can occur in aprender-shell operations.
Each variant provides specific context and actionable hints for resolution. This eliminates the Cloudflare-class defects caused by unwrap()/expect().
Variants
ModelNotFound
Model file was not found at the expected path
ModelCorrupted
Model file exists but is corrupted (checksum mismatch, invalid format)
ModelLoadFailed
Generic model loading failure
InvalidInput
Invalid input provided to a command
HistoryParseError
Error parsing history file
SecurityViolation
Security violation detected (sensitive command blocked)